/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package com.sun.appserv.management.base;

import java.util.Map;
import java.util.List;

import com.sun.appserv.management.util.misc.ExceptionUtil;

/**
	Provides various routines for system status.
    <p>
    <b>WARNING: some of these routines may be relocated.</b>
    @see SystemInfo
 */
public interface SystemStatus extends AMX, Utility, Singleton
{
/** The j2eeType as returned by {@link com.sun.appserv.management.base.AMX#getJ2EEType}. */
	public static final String	J2EE_TYPE			= XTypes.SYSTEM_STATUS;
        
    /** Key into Map returned by various methods including {@link #pingJDBCConnectionPool} */
    public static final String PING_SUCCEEDED_KEY = "PingSucceededKey";
    
    /** @deprecated use ExceptionUtil.MESSAGE_KEY */
    public static final String REASON_FAILED_KEY = ExceptionUtil.MESSAGE_KEY;
    
    /**
        Ping the JDBCConnectionPool and return status.  Various values can be found in the
        resulting Map.
        @see #PING_SUCCEEDED_KEY
        @see #REASON_FAILED_KEY
        @see com.sun.appserv.management.util.misc.ExceptionUtil#toMap
     */
    public Map<String,Object> pingJDBCConnectionPool( final String poolName );
    
    
    /**
        <em>Note: this API is highly volatile and subject to change<em>.
        <p>
        Query configuration changes that require restart.
        <p>
        Changes are listed oldest first.  The system may drop older changes in order to limit the size
        of the list and/or merge related changes to the most recent.
        <p>
        Over the wire transmission of 'UnprocessedConfigChange' would require the client to have its class;
        as delivered the Object[] contains only standard JDK types.
        See the Javadoc for {@link UnprocessedConfigChange} for the order of values in the Object[].
        Clients with access to the class can use {@link SystemStatus.Helper#toUnprocessedConfigChange}
     */
    public List<Object[]>  getRestartRequiredChanges();
    
    /** helper class, in particular to convert results from {@link #getRestartRequiredChanges} */
    public final class Helper {
        private Helper() {}
        public List<UnprocessedConfigChange>  toUnprocessedConfigChange( final List<Object[]> items) {
            final List<UnprocessedConfigChange> l = new java.util.ArrayList<UnprocessedConfigChange>();
            for( final Object[] a : items ) {
                l.add( new UnprocessedConfigChange(a) );
            }
            return l;
        }
    }
}










